@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.2.4';
+$VERSION = '0.2.5';
 ##------------------------------------------------------------------------------
 package sqlQuery;
 
@@ -393,8 +393,13 @@ sub _convertArgument
 			return sqlValueString->new($arg);
 		} elsif ('ARRAY' eq ref $arg) {
 			return sqlValueList->new($arg);
-		} elsif (blessed $arg && $arg->isa('sqlParameter')) {
-			return $arg;
+		} elsif (blessed $arg) {
+			return $arg if $arg->isa('sqlParameter');
+			return unless $arg->can('to_string');
+			my $value = $arg->to_string();
+			return sqlValueNull->new() unless defined $value;
+			return $value if blessed $value && $value->isa('sqlParameter');
+			return sqlValueString->new($value);
 		}
 
 		return
@@ -2044,7 +2049,7 @@ Oliver Schieche E<lt>schiecheo@cpan.orgE<gt>
 
 http://perfect-co.de/
 
-$Id: OO.pm 53 2015-09-03 13:18:00Z schieche $
+$Id: OO.pm 54 2016-03-02 07:02:07Z schieche $
 
 =head1 LICENSE AND COPYRIGHT
 
